==> route53-patterns-1.60.0-sources.jar: software/amazon/awscdk/services/route53/patterns/HttpsRedirect.java <==
package software.amazon.awscdk.services.route53.patterns;

/**
 * Allows creating a domainA -> domainB redirect using CloudFront and S3.
 * <p>
 * You can specify multiple domains to be redirected.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:33.054Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.route53.patterns.$Module.class, fqn = "@aws-cdk/aws-route53-patterns.HttpsRedirect")
public class HttpsRedirect extends software.amazon.awscdk.core.Construct {

    protected HttpsRedirect(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected HttpsRedirect(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public HttpsRedirect(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.route53.patterns.HttpsRedirectProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * A fluent builder for {@link software.amazon.awscdk.services.route53.patterns.HttpsRedirect}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.route53.patterns.HttpsRedirect> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.amazon.awscdk.core.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awscdk.services.route53.patterns.HttpsRedirectProps.Builder props;

        private Builder(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awscdk.services.route53.patterns.HttpsRedirectProps.Builder();
        }

        /**
         * The redirect target fully qualified domain name (FQDN).
         * <p>
         * An alias record
         * will be created that points to your CloudFront distribution. Root domain
         * or sub-domain can be supplied.
         * <p>
         * @return {@code this}
         * @param targetDomain The redirect target fully qualified domain name (FQDN). This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder targetDomain(final java.lang.String targetDomain) {
            this.props.targetDomain(targetDomain);
            return this;
        }

        /**
         * Hosted zone of the domain which will be used to create alias record(s) from domain names in the hosted zone to the target domain.
         * <p>
         * The hosted zone must
         * contain entries for the domain name(s) supplied through <code>recordNames</code> that
         * will redirect to the target domain.
         * <p>
         * Domain names in the hosted zone can include a specific domain (example.com)
         * and its subdomains (acme.example.com, zenith.example.com).
         * <p>
         * @return {@code this}
         * @param zone Hosted zone of the domain which will be used to create alias record(s) from domain names in the hosted zone to the target domain. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder zone(final software.amazon.awscdk.services.route53.IHostedZone zone) {
            this.props.zone(zone);
            return this;
        }

        /**
         * The AWS Certificate Manager (ACM) certificate that will be associated with the CloudFront distribution that will be created.
         * <p>
         * If provided, the certificate must be
         * stored in us-east-1 (N. Virginia)
         * <p>
         * Default: - A new certificate is created in us-east-1 (N. Virginia)
         * <p>
         * @return {@code this}
         * @param certificate The AWS Certificate Manager (ACM) certificate that will be associated with the CloudFront distribution that will be created. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder certificate(final software.amazon.awscdk.services.certificatemanager.ICertificate certificate) {
            this.props.certificate(certificate);
            return this;
        }

        /**
         * The domain names that will redirect to `targetDomain`.
         * <p>
         * Default: - the domain name of the hosted zone
         * <p>
         * @return {@code this}
         * @param recordNames The domain names that will redirect to `targetDomain`. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder recordNames(final java.util.List<java.lang.String> recordNames) {
            this.props.recordNames(recordNames);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.route53.patterns.HttpsRedirect}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public software.amazon.awscdk.services.route53.patterns.HttpsRedirect build() {
            return new software.amazon.awscdk.services.route53.patterns.HttpsRedirect(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}

==> route53-patterns-1.173.0-sources.jar: software/amazon/awscdk/services/route53/patterns/HttpsRedirect.java <==
package software.amazon.awscdk.services.route53.patterns;

/**
 * Allows creating a domainA -> domainB redirect using CloudFront and S3.
 * <p>
 * You can specify multiple domains to be redirected.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * HttpsRedirect.Builder.create(this, "Redirect")
 *         .recordNames(List.of("foo.example.com"))
 *         .targetDomain("bar.example.com")
 *         .zone(HostedZone.fromHostedZoneAttributes(this, "HostedZone", HostedZoneAttributes.builder()
 *                 .hostedZoneId("ID")
 *                 .zoneName("example.com")
 *                 .build()))
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.67.0 (build 2c027f5)", date = "2022-09-16T18:50:35.948Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.route53.patterns.$Module.class, fqn = "@aws-cdk/aws-route53-patterns.HttpsRedirect")
public class HttpsRedirect extends software.amazon.awscdk.core.Construct {

    protected HttpsRedirect(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected HttpsRedirect(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public HttpsRedirect(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.route53.patterns.HttpsRedirectProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * A fluent builder for {@link software.amazon.awscdk.services.route53.patterns.HttpsRedirect}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.route53.patterns.HttpsRedirect> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awscdk.services.route53.patterns.HttpsRedirectProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awscdk.services.route53.patterns.HttpsRedirectProps.Builder();
        }

        /**
         * The redirect target fully qualified domain name (FQDN).
         * <p>
         * An alias record
         * will be created that points to your CloudFront distribution. Root domain
         * or sub-domain can be supplied.
         * <p>
         * @return {@code this}
         * @param targetDomain The redirect target fully qualified domain name (FQDN). This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder targetDomain(final java.lang.String targetDomain) {
            this.props.targetDomain(targetDomain);
            return this;
        }

        /**
         * Hosted zone of the domain which will be used to create alias record(s) from domain names in the hosted zone to the target domain.
         * <p>
         * The hosted zone must
         * contain entries for the domain name(s) supplied through <code>recordNames</code> that
         * will redirect to the target domain.
         * <p>
         * Domain names in the hosted zone can include a specific domain (example.com)
         * and its subdomains (acme.example.com, zenith.example.com).
         * <p>
         * @return {@code this}
         * @param zone Hosted zone of the domain which will be used to create alias record(s) from domain names in the hosted zone to the target domain. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder zone(final software.amazon.awscdk.services.route53.IHostedZone zone) {
            this.props.zone(zone);
            return this;
        }

        /**
         * The AWS Certificate Manager (ACM) certificate that will be associated with the CloudFront distribution that will be created.
         * <p>
         * If provided, the certificate must be
         * stored in us-east-1 (N. Virginia)
         * <p>
         * Default: - A new certificate is created in us-east-1 (N. Virginia)
         * <p>
         * @return {@code this}
         * @param certificate The AWS Certificate Manager (ACM) certificate that will be associated with the CloudFront distribution that will be created. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder certificate(final software.amazon.awscdk.services.certificatemanager.ICertificate certificate) {
            this.props.certificate(certificate);
            return this;
        }

        /**
         * The domain names that will redirect to `targetDomain`.
         * <p>
         * Default: - the domain name of the hosted zone
         * <p>
         * @return {@code this}
         * @param recordNames The domain names that will redirect to `targetDomain`. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder recordNames(final java.util.List<java.lang.String> recordNames) {
            this.props.recordNames(recordNames);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.route53.patterns.HttpsRedirect}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public software.amazon.awscdk.services.route53.patterns.HttpsRedirect build() {
            return new software.amazon.awscdk.services.route53.patterns.HttpsRedirect(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}
